#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="CalendarDto.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.attachment import Attachment
from AsposeEmailCloudSdk.models.calendar_reminder import CalendarReminder
from AsposeEmailCloudSdk.models.mail_address import MailAddress
from AsposeEmailCloudSdk.models.recurrence_pattern_dto import RecurrencePatternDto


class CalendarDto(object):
    """iCalendar document representation.             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'attachments': 'list[Attachment]',
        'attendees': 'list[MailAddress]',
        'description': 'str',
        'end_date': 'datetime',
        'end_time_zone': 'str',
        'flags': 'list[str]',
        'is_description_html': 'bool',
        'location': 'str',
        'method': 'str',
        'microsoft_busy_status': 'str',
        'microsoft_intended_status': 'str',
        'optional_attendees': 'list[MailAddress]',
        'organizer': 'MailAddress',
        'recurrence_string': 'str',
        'recurrence': 'RecurrencePatternDto',
        'reminders': 'list[CalendarReminder]',
        'sequence_id': 'str',
        'start_date': 'datetime',
        'start_time_zone': 'str',
        'status': 'str',
        'summary': 'str',
        'transparency': 'str'
    }

    attribute_map = {
        'attachments': 'attachments',
        'attendees': 'attendees',
        'description': 'description',
        'end_date': 'endDate',
        'end_time_zone': 'endTimeZone',
        'flags': 'flags',
        'is_description_html': 'isDescriptionHtml',
        'location': 'location',
        'method': 'method',
        'microsoft_busy_status': 'microsoftBusyStatus',
        'microsoft_intended_status': 'microsoftIntendedStatus',
        'optional_attendees': 'optionalAttendees',
        'organizer': 'organizer',
        'recurrence_string': 'recurrenceString',
        'recurrence': 'recurrence',
        'reminders': 'reminders',
        'sequence_id': 'sequenceId',
        'start_date': 'startDate',
        'start_time_zone': 'startTimeZone',
        'status': 'status',
        'summary': 'summary',
        'transparency': 'transparency'
    }

    def __init__(self, attachments: List[Attachment] = None, attendees: List[MailAddress] = None, description: str = None, end_date: datetime = None, end_time_zone: str = None, flags: List[str] = None, is_description_html: bool = None, location: str = None, method: str = None, microsoft_busy_status: str = None, microsoft_intended_status: str = None, optional_attendees: List[MailAddress] = None, organizer: MailAddress = None, recurrence_string: str = None, recurrence: RecurrencePatternDto = None, reminders: List[CalendarReminder] = None, sequence_id: str = None, start_date: datetime = None, start_time_zone: str = None, status: str = None, summary: str = None, transparency: str = None):
        """
        iCalendar document representation.             
        :param attachments: Document attachments.
        :type attachments: List[Attachment]
        :param attendees: Event attendees.
        :type attendees: List[MailAddress]
        :param description: Description.
        :type description: str
        :param end_date: End date.
        :type end_date: datetime
        :param end_time_zone: End time zone.
        :type end_time_zone: str
        :param flags: Appointment flags.
        :type flags: List[str]
        :param is_description_html: Indicates if description is in HTML format.
        :type is_description_html: bool
        :param location: Location.
        :type location: str
        :param method: Defines the iCalendar object method type associated with the calendar document. Enum, available values: None, Publish, Request, Reply, Add, Cancel, Refresh, Counter, DeclineCounter
        :type method: str
        :param microsoft_busy_status: Specifies the BUSY status. Enum, available values: NotDefined, Free, Tentative, Busy, Oof
        :type microsoft_busy_status: str
        :param microsoft_intended_status: Specifies the INTENDED status. Enum, available values: NotDefined, Free, Tentative, Busy, Oof
        :type microsoft_intended_status: str
        :param optional_attendees: Optional attendees.             
        :type optional_attendees: List[MailAddress]
        :param organizer: Event organizer.             
        :type organizer: MailAddress
        :param recurrence_string: Deprecated, use 'Recurrence' property. String representation of recurrence pattern (See iCalendar RFC, \"Recurrence rule\" section). For example:               For daily recurrence:         \"FREQ=DAILY;COUNT=10;WKST=MO\"                   For monthly recurrence:         \"BYSETPOS=1;BYDAY=MO,TU,WE,TH,FR;FREQ=MONTHLY;INTERVAL=10;WKST=MO\"                   For yearly recurrence:         \"BYMONTHDAY=30;BYMONTH=1;FREQ=YEARLY;WKST=MO\"                   
        :type recurrence_string: str
        :param recurrence: Recurrence pattern             
        :type recurrence: RecurrencePatternDto
        :param reminders: Reminders.
        :type reminders: List[CalendarReminder]
        :param sequence_id: The sequence id. Read only.
        :type sequence_id: str
        :param start_date: Start date.
        :type start_date: datetime
        :param start_time_zone: Start time zone.
        :type start_time_zone: str
        :param status: Defines the overall status or confirmation for the calendar document. Enum, available values: NotDefined, Cancelled, Tentative, Confirmed
        :type status: str
        :param summary: Summary.
        :type summary: str
        :param transparency: Specifies whether or not this appointment is intended to be visible in availability searches. Enum, available values: NotDefined, Transparent, Opaque
        :type transparency: str
        """

        self._attachments = None
        self._attendees = None
        self._description = None
        self._end_date = None
        self._end_time_zone = None
        self._flags = None
        self._is_description_html = None
        self._location = None
        self._method = None
        self._microsoft_busy_status = None
        self._microsoft_intended_status = None
        self._optional_attendees = None
        self._organizer = None
        self._recurrence_string = None
        self._recurrence = None
        self._reminders = None
        self._sequence_id = None
        self._start_date = None
        self._start_time_zone = None
        self._status = None
        self._summary = None
        self._transparency = None

        if attachments is not None:
            self.attachments = attachments
        if attendees is not None:
            self.attendees = attendees
        if description is not None:
            self.description = description
        if end_date is not None:
            self.end_date = end_date
        if end_time_zone is not None:
            self.end_time_zone = end_time_zone
        if flags is not None:
            self.flags = flags
        if is_description_html is not None:
            self.is_description_html = is_description_html
        if location is not None:
            self.location = location
        if method is not None:
            self.method = method
        if microsoft_busy_status is not None:
            self.microsoft_busy_status = microsoft_busy_status
        if microsoft_intended_status is not None:
            self.microsoft_intended_status = microsoft_intended_status
        if optional_attendees is not None:
            self.optional_attendees = optional_attendees
        if organizer is not None:
            self.organizer = organizer
        if recurrence_string is not None:
            self.recurrence_string = recurrence_string
        if recurrence is not None:
            self.recurrence = recurrence
        if reminders is not None:
            self.reminders = reminders
        if sequence_id is not None:
            self.sequence_id = sequence_id
        if start_date is not None:
            self.start_date = start_date
        if start_time_zone is not None:
            self.start_time_zone = start_time_zone
        if status is not None:
            self.status = status
        if summary is not None:
            self.summary = summary
        if transparency is not None:
            self.transparency = transparency


    @property
    def attachments(self) -> List[Attachment]:
        """
        Document attachments.

        :return: The attachments of this CalendarDto.
        :rtype: list[Attachment]
        """
        return self._attachments

    @attachments.setter
    def attachments(self, attachments: List[Attachment]):
        """
        Document attachments.

        :param attachments: The attachments of this CalendarDto.
        :type: list[Attachment]
        """
        self._attachments = attachments

    @property
    def attendees(self) -> List[MailAddress]:
        """
        Event attendees.

        :return: The attendees of this CalendarDto.
        :rtype: list[MailAddress]
        """
        return self._attendees

    @attendees.setter
    def attendees(self, attendees: List[MailAddress]):
        """
        Event attendees.

        :param attendees: The attendees of this CalendarDto.
        :type: list[MailAddress]
        """
        if attendees is None:
            raise ValueError("Invalid value for `attendees`, must not be `None`")
        self._attendees = attendees

    @property
    def description(self) -> str:
        """
        Description.

        :return: The description of this CalendarDto.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description: str):
        """
        Description.

        :param description: The description of this CalendarDto.
        :type: str
        """
        self._description = description

    @property
    def end_date(self) -> datetime:
        """
        End date.

        :return: The end_date of this CalendarDto.
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date: datetime):
        """
        End date.

        :param end_date: The end_date of this CalendarDto.
        :type: datetime
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")
        self._end_date = end_date

    @property
    def end_time_zone(self) -> str:
        """
        End time zone.

        :return: The end_time_zone of this CalendarDto.
        :rtype: str
        """
        return self._end_time_zone

    @end_time_zone.setter
    def end_time_zone(self, end_time_zone: str):
        """
        End time zone.

        :param end_time_zone: The end_time_zone of this CalendarDto.
        :type: str
        """
        self._end_time_zone = end_time_zone

    @property
    def flags(self) -> List[str]:
        """
        Appointment flags. Items: Enumerates iCalendar flags. Enum, available values: None, AllDayEvent

        :return: The flags of this CalendarDto.
        :rtype: list[str]
        """
        return self._flags

    @flags.setter
    def flags(self, flags: List[str]):
        """
        Appointment flags. Items: Enumerates iCalendar flags. Enum, available values: None, AllDayEvent

        :param flags: The flags of this CalendarDto.
        :type: list[str]
        """
        self._flags = flags

    @property
    def is_description_html(self) -> bool:
        """
        Indicates if description is in HTML format.

        :return: The is_description_html of this CalendarDto.
        :rtype: bool
        """
        return self._is_description_html

    @is_description_html.setter
    def is_description_html(self, is_description_html: bool):
        """
        Indicates if description is in HTML format.

        :param is_description_html: The is_description_html of this CalendarDto.
        :type: bool
        """
        if is_description_html is None:
            raise ValueError("Invalid value for `is_description_html`, must not be `None`")
        self._is_description_html = is_description_html

    @property
    def location(self) -> str:
        """
        Location.

        :return: The location of this CalendarDto.
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location: str):
        """
        Location.

        :param location: The location of this CalendarDto.
        :type: str
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")
        if location is not None and len(location) < 1:
            raise ValueError("Invalid value for `location`, length must be greater than or equal to `1`")
        self._location = location

    @property
    def method(self) -> str:
        """
        Defines the iCalendar object method type associated with the calendar document. Enum, available values: None, Publish, Request, Reply, Add, Cancel, Refresh, Counter, DeclineCounter

        :return: The method of this CalendarDto.
        :rtype: str
        """
        return self._method

    @method.setter
    def method(self, method: str):
        """
        Defines the iCalendar object method type associated with the calendar document. Enum, available values: None, Publish, Request, Reply, Add, Cancel, Refresh, Counter, DeclineCounter

        :param method: The method of this CalendarDto.
        :type: str
        """
        if method is None:
            raise ValueError("Invalid value for `method`, must not be `None`")
        self._method = method

    @property
    def microsoft_busy_status(self) -> str:
        """
        Specifies the BUSY status. Enum, available values: NotDefined, Free, Tentative, Busy, Oof

        :return: The microsoft_busy_status of this CalendarDto.
        :rtype: str
        """
        return self._microsoft_busy_status

    @microsoft_busy_status.setter
    def microsoft_busy_status(self, microsoft_busy_status: str):
        """
        Specifies the BUSY status. Enum, available values: NotDefined, Free, Tentative, Busy, Oof

        :param microsoft_busy_status: The microsoft_busy_status of this CalendarDto.
        :type: str
        """
        if microsoft_busy_status is None:
            raise ValueError("Invalid value for `microsoft_busy_status`, must not be `None`")
        self._microsoft_busy_status = microsoft_busy_status

    @property
    def microsoft_intended_status(self) -> str:
        """
        Specifies the INTENDED status. Enum, available values: NotDefined, Free, Tentative, Busy, Oof

        :return: The microsoft_intended_status of this CalendarDto.
        :rtype: str
        """
        return self._microsoft_intended_status

    @microsoft_intended_status.setter
    def microsoft_intended_status(self, microsoft_intended_status: str):
        """
        Specifies the INTENDED status. Enum, available values: NotDefined, Free, Tentative, Busy, Oof

        :param microsoft_intended_status: The microsoft_intended_status of this CalendarDto.
        :type: str
        """
        if microsoft_intended_status is None:
            raise ValueError("Invalid value for `microsoft_intended_status`, must not be `None`")
        self._microsoft_intended_status = microsoft_intended_status

    @property
    def optional_attendees(self) -> List[MailAddress]:
        """
        Optional attendees.             

        :return: The optional_attendees of this CalendarDto.
        :rtype: list[MailAddress]
        """
        return self._optional_attendees

    @optional_attendees.setter
    def optional_attendees(self, optional_attendees: List[MailAddress]):
        """
        Optional attendees.             

        :param optional_attendees: The optional_attendees of this CalendarDto.
        :type: list[MailAddress]
        """
        self._optional_attendees = optional_attendees

    @property
    def organizer(self) -> MailAddress:
        """
        Event organizer.             

        :return: The organizer of this CalendarDto.
        :rtype: MailAddress
        """
        return self._organizer

    @organizer.setter
    def organizer(self, organizer: MailAddress):
        """
        Event organizer.             

        :param organizer: The organizer of this CalendarDto.
        :type: MailAddress
        """
        if organizer is None:
            raise ValueError("Invalid value for `organizer`, must not be `None`")
        self._organizer = organizer

    @property
    def recurrence_string(self) -> str:
        """
        Deprecated, use 'Recurrence' property. String representation of recurrence pattern (See iCalendar RFC, \"Recurrence rule\" section). For example:               For daily recurrence:         \"FREQ=DAILY;COUNT=10;WKST=MO\"                   For monthly recurrence:         \"BYSETPOS=1;BYDAY=MO,TU,WE,TH,FR;FREQ=MONTHLY;INTERVAL=10;WKST=MO\"                   For yearly recurrence:         \"BYMONTHDAY=30;BYMONTH=1;FREQ=YEARLY;WKST=MO\"                   

        :return: The recurrence_string of this CalendarDto.
        :rtype: str
        """
        return self._recurrence_string

    @recurrence_string.setter
    def recurrence_string(self, recurrence_string: str):
        """
        Deprecated, use 'Recurrence' property. String representation of recurrence pattern (See iCalendar RFC, \"Recurrence rule\" section). For example:               For daily recurrence:         \"FREQ=DAILY;COUNT=10;WKST=MO\"                   For monthly recurrence:         \"BYSETPOS=1;BYDAY=MO,TU,WE,TH,FR;FREQ=MONTHLY;INTERVAL=10;WKST=MO\"                   For yearly recurrence:         \"BYMONTHDAY=30;BYMONTH=1;FREQ=YEARLY;WKST=MO\"                   

        :param recurrence_string: The recurrence_string of this CalendarDto.
        :type: str
        """
        self._recurrence_string = recurrence_string

    @property
    def recurrence(self) -> RecurrencePatternDto:
        """
        Recurrence pattern             

        :return: The recurrence of this CalendarDto.
        :rtype: RecurrencePatternDto
        """
        return self._recurrence

    @recurrence.setter
    def recurrence(self, recurrence: RecurrencePatternDto):
        """
        Recurrence pattern             

        :param recurrence: The recurrence of this CalendarDto.
        :type: RecurrencePatternDto
        """
        self._recurrence = recurrence

    @property
    def reminders(self) -> List[CalendarReminder]:
        """
        Reminders.

        :return: The reminders of this CalendarDto.
        :rtype: list[CalendarReminder]
        """
        return self._reminders

    @reminders.setter
    def reminders(self, reminders: List[CalendarReminder]):
        """
        Reminders.

        :param reminders: The reminders of this CalendarDto.
        :type: list[CalendarReminder]
        """
        self._reminders = reminders

    @property
    def sequence_id(self) -> str:
        """
        The sequence id. Read only.

        :return: The sequence_id of this CalendarDto.
        :rtype: str
        """
        return self._sequence_id

    @sequence_id.setter
    def sequence_id(self, sequence_id: str):
        """
        The sequence id. Read only.

        :param sequence_id: The sequence_id of this CalendarDto.
        :type: str
        """
        self._sequence_id = sequence_id

    @property
    def start_date(self) -> datetime:
        """
        Start date.

        :return: The start_date of this CalendarDto.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date: datetime):
        """
        Start date.

        :param start_date: The start_date of this CalendarDto.
        :type: datetime
        """
        if start_date is None:
            raise ValueError("Invalid value for `start_date`, must not be `None`")
        self._start_date = start_date

    @property
    def start_time_zone(self) -> str:
        """
        Start time zone.

        :return: The start_time_zone of this CalendarDto.
        :rtype: str
        """
        return self._start_time_zone

    @start_time_zone.setter
    def start_time_zone(self, start_time_zone: str):
        """
        Start time zone.

        :param start_time_zone: The start_time_zone of this CalendarDto.
        :type: str
        """
        self._start_time_zone = start_time_zone

    @property
    def status(self) -> str:
        """
        Defines the overall status or confirmation for the calendar document. Enum, available values: NotDefined, Cancelled, Tentative, Confirmed

        :return: The status of this CalendarDto.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status: str):
        """
        Defines the overall status or confirmation for the calendar document. Enum, available values: NotDefined, Cancelled, Tentative, Confirmed

        :param status: The status of this CalendarDto.
        :type: str
        """
        if status is None:
            raise ValueError("Invalid value for `status`, must not be `None`")
        self._status = status

    @property
    def summary(self) -> str:
        """
        Summary.

        :return: The summary of this CalendarDto.
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary: str):
        """
        Summary.

        :param summary: The summary of this CalendarDto.
        :type: str
        """
        self._summary = summary

    @property
    def transparency(self) -> str:
        """
        Specifies whether or not this appointment is intended to be visible in availability searches. Enum, available values: NotDefined, Transparent, Opaque

        :return: The transparency of this CalendarDto.
        :rtype: str
        """
        return self._transparency

    @transparency.setter
    def transparency(self, transparency: str):
        """
        Specifies whether or not this appointment is intended to be visible in availability searches. Enum, available values: NotDefined, Transparent, Opaque

        :param transparency: The transparency of this CalendarDto.
        :type: str
        """
        if transparency is None:
            raise ValueError("Invalid value for `transparency`, must not be `None`")
        self._transparency = transparency

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CalendarDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="contact_get_request.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from AsposeEmailCloudSdk.models import *


class ContactGetRequest(object):
    """
    Request model for contact_get operation.
    Initializes a new instance.

    :param format: Contact document format. Enum, available values: VCard, WebDav, Msg
    :type format: str
    :param file_name: Contact document file name.
    :type file_name: str
    :param folder: Path to folder in storage.
    :type folder: str
    :param storage: Storage name.
    :type storage: str
    """

    def __init__(self, format: str, file_name: str, folder: str = None, storage: str = None):
        """
        Request model for contact_get operation.
        Initializes a new instance.

        :param format: Contact document format. Enum, available values: VCard, WebDav, Msg
        :type format: str
        :param file_name: Contact document file name.
        :type file_name: str
        :param folder: Path to folder in storage.
        :type folder: str
        :param storage: Storage name.
        :type storage: str
        """

        self.format = format
        self.file_name = file_name
        self.folder = folder
        self.storage = storage



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="client_thread_api.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

from AsposeEmailCloudSdk.api.api_base import ApiBase
from AsposeEmailCloudSdk.models import *


class ClientThreadApi(ApiBase):
    """
    Aspose.Email Cloud API. ClientThreadApi operations.

    """

    def __init__(self, api_client):
        super(ClientThreadApi, self).__init__(api_client)

    def delete(self, request: ClientThreadDeleteRequest):
        """Delete thread by id. All messages from thread will also be deleted.             

        :param request: Delete email thread request.
        :type request: ClientThreadDeleteRequest
        :return: None
        """
        # verify the required parameter 'request' is set
        if request is None:
            raise ValueError("Missing the required parameter `request` when calling `delete`")

        collection_formats = {}
        path = '/email/client/thread'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = request
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'DELETE', None)

    def get_list(self, request: ClientThreadGetListRequest) -> EmailThreadList:
        """Get message threads from folder. All messages are partly fetched (without email body and some other fields).             


        :param request: ClientThreadGetListRequest object with parameters
        :type request: ClientThreadGetListRequest
        :return: EmailThreadList
        """
        # verify the required parameter 'folder' is set
        if request.folder is None:
            raise ValueError("Missing the required parameter `folder` when calling `get_list`")
        # verify the required parameter 'account' is set
        if request.account is None:
            raise ValueError("Missing the required parameter `account` when calling `get_list`")

        collection_formats = {}
        path = '/email/client/thread/list'
        path_params = {}

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('folder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.folder if request.folder is not None else '')
        else:
            if request.folder is not None:
                query_params.append((self._lowercase_first_letter('folder'), request.folder))
        path_parameter = '{' + self._lowercase_first_letter('account') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.account if request.account is not None else '')
        else:
            if request.account is not None:
                query_params.append((self._lowercase_first_letter('account'), request.account))
        path_parameter = '{' + self._lowercase_first_letter('storage') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage if request.storage is not None else '')
        else:
            if request.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), request.storage))
        path_parameter = '{' + self._lowercase_first_letter('accountStorageFolder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.account_storage_folder if request.account_storage_folder is not None else '')
        else:
            if request.account_storage_folder is not None:
                query_params.append((self._lowercase_first_letter('accountStorageFolder'), request.account_storage_folder))
        path_parameter = '{' + self._lowercase_first_letter('updateFolderCache') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.update_folder_cache if request.update_folder_cache is not None else '')
        else:
            if request.update_folder_cache is not None:
                query_params.append((self._lowercase_first_letter('updateFolderCache'), request.update_folder_cache))
        path_parameter = '{' + self._lowercase_first_letter('messagesCacheLimit') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.messages_cache_limit if request.messages_cache_limit is not None else '')
        else:
            if request.messages_cache_limit is not None:
                query_params.append((self._lowercase_first_letter('messagesCacheLimit'), request.messages_cache_limit))

        form_params = []
        local_var_files = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'GET', 'EmailThreadList')

    def get_messages(self, request: ClientThreadGetMessagesRequest) -> EmailList:
        """Get messages from thread by id. All messages are fully fetched. For accounts with CacheFile only cached messages will be returned.             


        :param request: ClientThreadGetMessagesRequest object with parameters
        :type request: ClientThreadGetMessagesRequest
        :return: EmailList
        """
        # verify the required parameter 'thread_id' is set
        if request.thread_id is None:
            raise ValueError("Missing the required parameter `thread_id` when calling `get_messages`")
        # verify the required parameter 'account' is set
        if request.account is None:
            raise ValueError("Missing the required parameter `account` when calling `get_messages`")

        collection_formats = {}
        path = '/email/client/thread/messages'
        path_params = {}

        query_params = []
        path_parameter = '{' + self._lowercase_first_letter('threadId') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.thread_id if request.thread_id is not None else '')
        else:
            if request.thread_id is not None:
                query_params.append((self._lowercase_first_letter('threadId'), request.thread_id))
        path_parameter = '{' + self._lowercase_first_letter('account') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.account if request.account is not None else '')
        else:
            if request.account is not None:
                query_params.append((self._lowercase_first_letter('account'), request.account))
        path_parameter = '{' + self._lowercase_first_letter('folder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.folder if request.folder is not None else '')
        else:
            if request.folder is not None:
                query_params.append((self._lowercase_first_letter('folder'), request.folder))
        path_parameter = '{' + self._lowercase_first_letter('storage') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.storage if request.storage is not None else '')
        else:
            if request.storage is not None:
                query_params.append((self._lowercase_first_letter('storage'), request.storage))
        path_parameter = '{' + self._lowercase_first_letter('accountStorageFolder') + '}'
        if path_parameter in path:
            path = path.replace(path_parameter, request.account_storage_folder if request.account_storage_folder is not None else '')
        else:
            if request.account_storage_folder is not None:
                query_params.append((self._lowercase_first_letter('accountStorageFolder'), request.account_storage_folder))

        form_params = []
        local_var_files = []

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])

        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, path_params, query_params, header_params, form_params, None, local_var_files,
                                          collection_formats, auth_settings)

        return self._make_request(http_request_object, 'GET', 'EmailList')

    def move(self, request: ClientThreadMoveRequest):
        """Move thread to another folder.             

        :param request: Move thread request.
        :type request: ClientThreadMoveRequest
        :return: None
        """
        # verify the required parameter 'request' is set
        if request is None:
            raise ValueError("Missing the required parameter `request` when calling `move`")

        collection_formats = {}
        path = '/email/client/thread/move'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = request
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'PUT', None)

    def set_is_read(self, request: ClientThreadSetIsReadRequest):
        """Mark all messages in thread as read or unread.             

        :param request: Email account specifier and IsRead flag.
        :type request: ClientThreadSetIsReadRequest
        :return: None
        """
        # verify the required parameter 'request' is set
        if request is None:
            raise ValueError("Missing the required parameter `request` when calling `set_is_read`")

        collection_formats = {}
        path = '/email/client/thread/set-is-read'

        header_params = {}
        # HTTP header `Accept`
        header_params['Accept'] = self._select_header_accept(
            ['application/json'])
        # HTTP header `Content-Type`
        header_params['Content-Type'] = self._select_header_content_type(
            ['application/json'])
        body_params = request
        # Authentication setting
        auth_settings = ['JWT']

        http_request_object = HttpRequest(path, None, None, header_params, None, body_params, None, None, auth_settings)

        return self._make_request(http_request_object, 'PUT', None)




#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="__init__.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

# import models into model package
from AsposeEmailCloudSdk.models.ai_bcr_image import AiBcrImage
from AsposeEmailCloudSdk.models.ai_bcr_options import AiBcrOptions
from AsposeEmailCloudSdk.models.ai_bcr_parse_storage_request import AiBcrParseStorageRequest
from AsposeEmailCloudSdk.models.ai_name_component import AiNameComponent
from AsposeEmailCloudSdk.models.ai_name_cultural_context import AiNameCulturalContext
from AsposeEmailCloudSdk.models.ai_name_extracted import AiNameExtracted
from AsposeEmailCloudSdk.models.ai_name_extracted_component import AiNameExtractedComponent
from AsposeEmailCloudSdk.models.ai_name_formatted import AiNameFormatted
from AsposeEmailCloudSdk.models.ai_name_gender_hypothesis import AiNameGenderHypothesis
from AsposeEmailCloudSdk.models.ai_name_match_result import AiNameMatchResult
from AsposeEmailCloudSdk.models.ai_name_mismatch import AiNameMismatch
from AsposeEmailCloudSdk.models.ai_name_parsed_request import AiNameParsedRequest
from AsposeEmailCloudSdk.models.ai_name_weighted import AiNameWeighted
from AsposeEmailCloudSdk.models.ai_name_weighted_variants import AiNameWeightedVariants
from AsposeEmailCloudSdk.models.associated_person import AssociatedPerson
from AsposeEmailCloudSdk.models.attachment_base import AttachmentBase
from AsposeEmailCloudSdk.models.calendar_as_alternate_request import CalendarAsAlternateRequest
from AsposeEmailCloudSdk.models.calendar_as_file_request import CalendarAsFileRequest
from AsposeEmailCloudSdk.models.calendar_dto import CalendarDto
from AsposeEmailCloudSdk.models.calendar_reminder import CalendarReminder
from AsposeEmailCloudSdk.models.client_account_base_request import ClientAccountBaseRequest
from AsposeEmailCloudSdk.models.contact_as_file_request import ContactAsFileRequest
from AsposeEmailCloudSdk.models.contact_dto import ContactDto
from AsposeEmailCloudSdk.models.contact_photo import ContactPhoto
from AsposeEmailCloudSdk.models.content_type import ContentType
from AsposeEmailCloudSdk.models.content_type_parameter import ContentTypeParameter
from AsposeEmailCloudSdk.models.customer_event import CustomerEvent
from AsposeEmailCloudSdk.models.disc_usage import DiscUsage
from AsposeEmailCloudSdk.models.discover_email_config_request import DiscoverEmailConfigRequest
from AsposeEmailCloudSdk.models.email_account_config import EmailAccountConfig
from AsposeEmailCloudSdk.models.email_address import EmailAddress
from AsposeEmailCloudSdk.models.email_as_file_request import EmailAsFileRequest
from AsposeEmailCloudSdk.models.email_client_account import EmailClientAccount
from AsposeEmailCloudSdk.models.email_client_account_credentials import EmailClientAccountCredentials
from AsposeEmailCloudSdk.models.email_client_multi_account import EmailClientMultiAccount
from AsposeEmailCloudSdk.models.email_dto import EmailDto
from AsposeEmailCloudSdk.models.email_thread import EmailThread
from AsposeEmailCloudSdk.models.enum_with_custom_of_associated_person_category import EnumWithCustomOfAssociatedPersonCategory
from AsposeEmailCloudSdk.models.enum_with_custom_of_email_address_category import EnumWithCustomOfEmailAddressCategory
from AsposeEmailCloudSdk.models.enum_with_custom_of_event_category import EnumWithCustomOfEventCategory
from AsposeEmailCloudSdk.models.enum_with_custom_of_instant_messenger_category import EnumWithCustomOfInstantMessengerCategory
from AsposeEmailCloudSdk.models.enum_with_custom_of_phone_number_category import EnumWithCustomOfPhoneNumberCategory
from AsposeEmailCloudSdk.models.enum_with_custom_of_postal_address_category import EnumWithCustomOfPostalAddressCategory
from AsposeEmailCloudSdk.models.enum_with_custom_of_url_category import EnumWithCustomOfUrlCategory
from AsposeEmailCloudSdk.models.error import Error
from AsposeEmailCloudSdk.models.error_details import ErrorDetails
from AsposeEmailCloudSdk.models.file_versions import FileVersions
from AsposeEmailCloudSdk.models.files_list import FilesList
from AsposeEmailCloudSdk.models.files_upload_result import FilesUploadResult
from AsposeEmailCloudSdk.models.instant_messenger_address import InstantMessengerAddress
from AsposeEmailCloudSdk.models.list_response_of_ai_name_component import ListResponseOfAiNameComponent
from AsposeEmailCloudSdk.models.list_response_of_ai_name_extracted import ListResponseOfAiNameExtracted
from AsposeEmailCloudSdk.models.list_response_of_ai_name_gender_hypothesis import ListResponseOfAiNameGenderHypothesis
from AsposeEmailCloudSdk.models.list_response_of_contact_dto import ListResponseOfContactDto
from AsposeEmailCloudSdk.models.list_response_of_email_account_config import ListResponseOfEmailAccountConfig
from AsposeEmailCloudSdk.models.list_response_of_email_dto import ListResponseOfEmailDto
from AsposeEmailCloudSdk.models.list_response_of_email_thread import ListResponseOfEmailThread
from AsposeEmailCloudSdk.models.list_response_of_mail_message_base import ListResponseOfMailMessageBase
from AsposeEmailCloudSdk.models.list_response_of_mail_server_folder import ListResponseOfMailServerFolder
from AsposeEmailCloudSdk.models.list_response_of_storage_file_location import ListResponseOfStorageFileLocation
from AsposeEmailCloudSdk.models.list_response_of_storage_model_of_calendar_dto import ListResponseOfStorageModelOfCalendarDto
from AsposeEmailCloudSdk.models.list_response_of_storage_model_of_contact_dto import ListResponseOfStorageModelOfContactDto
from AsposeEmailCloudSdk.models.list_response_of_storage_model_of_email_dto import ListResponseOfStorageModelOfEmailDto
from AsposeEmailCloudSdk.models.mail_address import MailAddress
from AsposeEmailCloudSdk.models.mail_message_base import MailMessageBase
from AsposeEmailCloudSdk.models.mail_server_folder import MailServerFolder
from AsposeEmailCloudSdk.models.mapi_attachment_dto import MapiAttachmentDto
from AsposeEmailCloudSdk.models.mapi_calendar_as_file_request import MapiCalendarAsFileRequest
from AsposeEmailCloudSdk.models.mapi_calendar_attendees_dto import MapiCalendarAttendeesDto
from AsposeEmailCloudSdk.models.mapi_calendar_event_recurrence_dto import MapiCalendarEventRecurrenceDto
from AsposeEmailCloudSdk.models.mapi_calendar_exception_info_dto import MapiCalendarExceptionInfoDto
from AsposeEmailCloudSdk.models.mapi_calendar_recurrence_pattern_dto import MapiCalendarRecurrencePatternDto
from AsposeEmailCloudSdk.models.mapi_calendar_time_zone_dto import MapiCalendarTimeZoneDto
from AsposeEmailCloudSdk.models.mapi_calendar_time_zone_info_dto import MapiCalendarTimeZoneInfoDto
from AsposeEmailCloudSdk.models.mapi_calendar_time_zone_rule_dto import MapiCalendarTimeZoneRuleDto
from AsposeEmailCloudSdk.models.mapi_contact_as_file_request import MapiContactAsFileRequest
from AsposeEmailCloudSdk.models.mapi_contact_electronic_address_dto import MapiContactElectronicAddressDto
from AsposeEmailCloudSdk.models.mapi_contact_electronic_address_property_set_dto import MapiContactElectronicAddressPropertySetDto
from AsposeEmailCloudSdk.models.mapi_contact_event_property_set_dto import MapiContactEventPropertySetDto
from AsposeEmailCloudSdk.models.mapi_contact_name_property_set_dto import MapiContactNamePropertySetDto
from AsposeEmailCloudSdk.models.mapi_contact_other_property_set_dto import MapiContactOtherPropertySetDto
from AsposeEmailCloudSdk.models.mapi_contact_personal_info_property_set_dto import MapiContactPersonalInfoPropertySetDto
from AsposeEmailCloudSdk.models.mapi_contact_physical_address_dto import MapiContactPhysicalAddressDto
from AsposeEmailCloudSdk.models.mapi_contact_physical_address_property_set_dto import MapiContactPhysicalAddressPropertySetDto
from AsposeEmailCloudSdk.models.mapi_contact_professional_property_set_dto import MapiContactProfessionalPropertySetDto
from AsposeEmailCloudSdk.models.mapi_contact_telephone_property_set_dto import MapiContactTelephonePropertySetDto
from AsposeEmailCloudSdk.models.mapi_electronic_address_dto import MapiElectronicAddressDto
from AsposeEmailCloudSdk.models.mapi_message_as_file_request import MapiMessageAsFileRequest
from AsposeEmailCloudSdk.models.mapi_message_item_base_dto import MapiMessageItemBaseDto
from AsposeEmailCloudSdk.models.mapi_property_descriptor import MapiPropertyDescriptor
from AsposeEmailCloudSdk.models.mapi_property_dto import MapiPropertyDto
from AsposeEmailCloudSdk.models.mapi_recipient_dto import MapiRecipientDto
from AsposeEmailCloudSdk.models.name_value_pair import NameValuePair
from AsposeEmailCloudSdk.models.object_exist import ObjectExist
from AsposeEmailCloudSdk.models.phone_number import PhoneNumber
from AsposeEmailCloudSdk.models.postal_address import PostalAddress
from AsposeEmailCloudSdk.models.recurrence_pattern_dto import RecurrencePatternDto
from AsposeEmailCloudSdk.models.reminder_attendee import ReminderAttendee
from AsposeEmailCloudSdk.models.reminder_trigger import ReminderTrigger
from AsposeEmailCloudSdk.models.storage_exist import StorageExist
from AsposeEmailCloudSdk.models.storage_file import StorageFile
from AsposeEmailCloudSdk.models.storage_folder_location import StorageFolderLocation
from AsposeEmailCloudSdk.models.storage_model_of_calendar_dto import StorageModelOfCalendarDto
from AsposeEmailCloudSdk.models.storage_model_of_contact_dto import StorageModelOfContactDto
from AsposeEmailCloudSdk.models.storage_model_of_email_client_account import StorageModelOfEmailClientAccount
from AsposeEmailCloudSdk.models.storage_model_of_email_client_multi_account import StorageModelOfEmailClientMultiAccount
from AsposeEmailCloudSdk.models.storage_model_of_email_dto import StorageModelOfEmailDto
from AsposeEmailCloudSdk.models.storage_model_of_mapi_calendar_dto import StorageModelOfMapiCalendarDto
from AsposeEmailCloudSdk.models.storage_model_of_mapi_contact_dto import StorageModelOfMapiContactDto
from AsposeEmailCloudSdk.models.storage_model_of_mapi_message_dto import StorageModelOfMapiMessageDto
from AsposeEmailCloudSdk.models.url import Url
from AsposeEmailCloudSdk.models.value_t_of_boolean import ValueTOfBoolean
from AsposeEmailCloudSdk.models.value_t_of_string import ValueTOfString
from AsposeEmailCloudSdk.models.ai_bcr_image_storage_file import AiBcrImageStorageFile
from AsposeEmailCloudSdk.models.ai_name_component_list import AiNameComponentList
from AsposeEmailCloudSdk.models.ai_name_extracted_list import AiNameExtractedList
from AsposeEmailCloudSdk.models.ai_name_gender_hypothesis_list import AiNameGenderHypothesisList
from AsposeEmailCloudSdk.models.ai_name_match_parsed_request import AiNameMatchParsedRequest
from AsposeEmailCloudSdk.models.alternate_view import AlternateView
from AsposeEmailCloudSdk.models.attachment import Attachment
from AsposeEmailCloudSdk.models.calendar_save_request import CalendarSaveRequest
from AsposeEmailCloudSdk.models.calendar_storage_list import CalendarStorageList
from AsposeEmailCloudSdk.models.client_account_save_multi_request import ClientAccountSaveMultiRequest
from AsposeEmailCloudSdk.models.client_account_save_request import ClientAccountSaveRequest
from AsposeEmailCloudSdk.models.client_folder_create_request import ClientFolderCreateRequest
from AsposeEmailCloudSdk.models.client_folder_delete_request import ClientFolderDeleteRequest
from AsposeEmailCloudSdk.models.client_message_append_request import ClientMessageAppendRequest
from AsposeEmailCloudSdk.models.client_message_base_request import ClientMessageBaseRequest
from AsposeEmailCloudSdk.models.client_message_send_request import ClientMessageSendRequest
from AsposeEmailCloudSdk.models.client_thread_base_request import ClientThreadBaseRequest
from AsposeEmailCloudSdk.models.contact_list import ContactList
from AsposeEmailCloudSdk.models.contact_save_request import ContactSaveRequest
from AsposeEmailCloudSdk.models.contact_storage_list import ContactStorageList
from AsposeEmailCloudSdk.models.daily_recurrence_pattern_dto import DailyRecurrencePatternDto
from AsposeEmailCloudSdk.models.email_account_config_list import EmailAccountConfigList
from AsposeEmailCloudSdk.models.email_client_account_oauth_credentials import EmailClientAccountOauthCredentials
from AsposeEmailCloudSdk.models.email_client_account_password_credentials import EmailClientAccountPasswordCredentials
from AsposeEmailCloudSdk.models.email_config_discover_oauth_request import EmailConfigDiscoverOauthRequest
from AsposeEmailCloudSdk.models.email_config_discover_password_request import EmailConfigDiscoverPasswordRequest
from AsposeEmailCloudSdk.models.email_list import EmailList
from AsposeEmailCloudSdk.models.email_save_request import EmailSaveRequest
from AsposeEmailCloudSdk.models.email_storage_list import EmailStorageList
from AsposeEmailCloudSdk.models.email_thread_list import EmailThreadList
from AsposeEmailCloudSdk.models.file_version import FileVersion
from AsposeEmailCloudSdk.models.linked_resource import LinkedResource
from AsposeEmailCloudSdk.models.mail_message_base64 import MailMessageBase64
from AsposeEmailCloudSdk.models.mail_message_base_list import MailMessageBaseList
from AsposeEmailCloudSdk.models.mail_message_dto import MailMessageDto
from AsposeEmailCloudSdk.models.mail_message_mapi import MailMessageMapi
from AsposeEmailCloudSdk.models.mail_server_folder_list import MailServerFolderList
from AsposeEmailCloudSdk.models.mapi_binary_property_dto import MapiBinaryPropertyDto
from AsposeEmailCloudSdk.models.mapi_boolean_property_dto import MapiBooleanPropertyDto
from AsposeEmailCloudSdk.models.mapi_calendar_daily_recurrence_pattern_dto import MapiCalendarDailyRecurrencePatternDto
from AsposeEmailCloudSdk.models.mapi_calendar_dto import MapiCalendarDto
from AsposeEmailCloudSdk.models.mapi_calendar_save_request import MapiCalendarSaveRequest
from AsposeEmailCloudSdk.models.mapi_calendar_weekly_recurrence_pattern_dto import MapiCalendarWeeklyRecurrencePatternDto
from AsposeEmailCloudSdk.models.mapi_calendar_yearly_and_monthly_recurrence_pattern_dto import MapiCalendarYearlyAndMonthlyRecurrencePatternDto
from AsposeEmailCloudSdk.models.mapi_contact_dto import MapiContactDto
from AsposeEmailCloudSdk.models.mapi_contact_photo_dto import MapiContactPhotoDto
from AsposeEmailCloudSdk.models.mapi_contact_save_request import MapiContactSaveRequest
from AsposeEmailCloudSdk.models.mapi_date_time_property_dto import MapiDateTimePropertyDto
from AsposeEmailCloudSdk.models.mapi_file_as_property_dto import MapiFileAsPropertyDto
from AsposeEmailCloudSdk.models.mapi_importance_property_dto import MapiImportancePropertyDto
from AsposeEmailCloudSdk.models.mapi_int_property_dto import MapiIntPropertyDto
from AsposeEmailCloudSdk.models.mapi_known_property_descriptor import MapiKnownPropertyDescriptor
from AsposeEmailCloudSdk.models.mapi_legacy_free_busy_property_dto import MapiLegacyFreeBusyPropertyDto
from AsposeEmailCloudSdk.models.mapi_message_dto import MapiMessageDto
from AsposeEmailCloudSdk.models.mapi_message_save_request import MapiMessageSaveRequest
from AsposeEmailCloudSdk.models.mapi_multi_int_property_dto import MapiMultiIntPropertyDto
from AsposeEmailCloudSdk.models.mapi_multi_string_property_dto import MapiMultiStringPropertyDto
from AsposeEmailCloudSdk.models.mapi_physical_address_index_property_dto import MapiPhysicalAddressIndexPropertyDto
from AsposeEmailCloudSdk.models.mapi_pid_property_descriptor import MapiPidPropertyDescriptor
from AsposeEmailCloudSdk.models.mapi_response_type_property_dto import MapiResponseTypePropertyDto
from AsposeEmailCloudSdk.models.mapi_string_property_dto import MapiStringPropertyDto
from AsposeEmailCloudSdk.models.monthly_recurrence_pattern_dto import MonthlyRecurrencePatternDto
from AsposeEmailCloudSdk.models.storage_file_location import StorageFileLocation
from AsposeEmailCloudSdk.models.storage_file_location_list import StorageFileLocationList
from AsposeEmailCloudSdk.models.task_regenerating_pattern_dto import TaskRegeneratingPatternDto
from AsposeEmailCloudSdk.models.weekly_recurrence_pattern_dto import WeeklyRecurrencePatternDto
from AsposeEmailCloudSdk.models.yearly_recurrence_pattern_dto import YearlyRecurrencePatternDto
from AsposeEmailCloudSdk.models.client_message_delete_request import ClientMessageDeleteRequest
from AsposeEmailCloudSdk.models.client_message_move_request import ClientMessageMoveRequest
from AsposeEmailCloudSdk.models.client_message_set_is_read_request import ClientMessageSetIsReadRequest
from AsposeEmailCloudSdk.models.client_thread_delete_request import ClientThreadDeleteRequest
from AsposeEmailCloudSdk.models.client_thread_move_request import ClientThreadMoveRequest
from AsposeEmailCloudSdk.models.client_thread_set_is_read_request import ClientThreadSetIsReadRequest
from AsposeEmailCloudSdk.models.mapi_pid_lid_property_descriptor import MapiPidLidPropertyDescriptor
from AsposeEmailCloudSdk.models.mapi_pid_name_property_descriptor import MapiPidNamePropertyDescriptor
from AsposeEmailCloudSdk.models.mapi_pid_tag_property_descriptor import MapiPidTagPropertyDescriptor
from AsposeEmailCloudSdk.models.http_request import HttpRequest
from AsposeEmailCloudSdk.models.ai_bcr_parse_request import AiBcrParseRequest
from AsposeEmailCloudSdk.models.ai_name_complete_request import AiNameCompleteRequest
from AsposeEmailCloudSdk.models.ai_name_expand_request import AiNameExpandRequest
from AsposeEmailCloudSdk.models.ai_name_format_request import AiNameFormatRequest
from AsposeEmailCloudSdk.models.ai_name_genderize_request import AiNameGenderizeRequest
from AsposeEmailCloudSdk.models.ai_name_match_request import AiNameMatchRequest
from AsposeEmailCloudSdk.models.ai_name_parse_request import AiNameParseRequest
from AsposeEmailCloudSdk.models.ai_name_parse_email_address_request import AiNameParseEmailAddressRequest
from AsposeEmailCloudSdk.models.calendar_convert_request import CalendarConvertRequest
from AsposeEmailCloudSdk.models.calendar_from_file_request import CalendarFromFileRequest
from AsposeEmailCloudSdk.models.calendar_get_request import CalendarGetRequest
from AsposeEmailCloudSdk.models.calendar_get_as_alternate_request import CalendarGetAsAlternateRequest
from AsposeEmailCloudSdk.models.calendar_get_as_file_request import CalendarGetAsFileRequest
from AsposeEmailCloudSdk.models.calendar_get_list_request import CalendarGetListRequest
from AsposeEmailCloudSdk.models.client_account_get_request import ClientAccountGetRequest
from AsposeEmailCloudSdk.models.client_account_get_multi_request import ClientAccountGetMultiRequest
from AsposeEmailCloudSdk.models.client_folder_get_list_request import ClientFolderGetListRequest
from AsposeEmailCloudSdk.models.client_message_append_file_request import ClientMessageAppendFileRequest
from AsposeEmailCloudSdk.models.client_message_fetch_request import ClientMessageFetchRequest
from AsposeEmailCloudSdk.models.client_message_fetch_file_request import ClientMessageFetchFileRequest
from AsposeEmailCloudSdk.models.client_message_list_request import ClientMessageListRequest
from AsposeEmailCloudSdk.models.client_message_send_file_request import ClientMessageSendFileRequest
from AsposeEmailCloudSdk.models.client_thread_get_list_request import ClientThreadGetListRequest
from AsposeEmailCloudSdk.models.client_thread_get_messages_request import ClientThreadGetMessagesRequest
from AsposeEmailCloudSdk.models.contact_convert_request import ContactConvertRequest
from AsposeEmailCloudSdk.models.contact_from_file_request import ContactFromFileRequest
from AsposeEmailCloudSdk.models.contact_get_request import ContactGetRequest
from AsposeEmailCloudSdk.models.contact_get_as_file_request import ContactGetAsFileRequest
from AsposeEmailCloudSdk.models.contact_get_list_request import ContactGetListRequest
from AsposeEmailCloudSdk.models.disposable_email_is_disposable_request import DisposableEmailIsDisposableRequest
from AsposeEmailCloudSdk.models.email_convert_request import EmailConvertRequest
from AsposeEmailCloudSdk.models.email_from_file_request import EmailFromFileRequest
from AsposeEmailCloudSdk.models.email_get_request import EmailGetRequest
from AsposeEmailCloudSdk.models.email_get_as_file_request import EmailGetAsFileRequest
from AsposeEmailCloudSdk.models.email_get_list_request import EmailGetListRequest
from AsposeEmailCloudSdk.models.email_config_discover_request import EmailConfigDiscoverRequest
from AsposeEmailCloudSdk.models.copy_file_request import CopyFileRequest
from AsposeEmailCloudSdk.models.delete_file_request import DeleteFileRequest
from AsposeEmailCloudSdk.models.download_file_request import DownloadFileRequest
from AsposeEmailCloudSdk.models.move_file_request import MoveFileRequest
from AsposeEmailCloudSdk.models.upload_file_request import UploadFileRequest
from AsposeEmailCloudSdk.models.copy_folder_request import CopyFolderRequest
from AsposeEmailCloudSdk.models.create_folder_request import CreateFolderRequest
from AsposeEmailCloudSdk.models.delete_folder_request import DeleteFolderRequest
from AsposeEmailCloudSdk.models.get_files_list_request import GetFilesListRequest
from AsposeEmailCloudSdk.models.move_folder_request import MoveFolderRequest
from AsposeEmailCloudSdk.models.mapi_calendar_from_file_request import MapiCalendarFromFileRequest
from AsposeEmailCloudSdk.models.mapi_calendar_get_request import MapiCalendarGetRequest
from AsposeEmailCloudSdk.models.mapi_contact_from_file_request import MapiContactFromFileRequest
from AsposeEmailCloudSdk.models.mapi_contact_get_request import MapiContactGetRequest
from AsposeEmailCloudSdk.models.mapi_message_from_file_request import MapiMessageFromFileRequest
from AsposeEmailCloudSdk.models.mapi_message_get_request import MapiMessageGetRequest
from AsposeEmailCloudSdk.models.get_disc_usage_request import GetDiscUsageRequest
from AsposeEmailCloudSdk.models.get_file_versions_request import GetFileVersionsRequest
from AsposeEmailCloudSdk.models.object_exists_request import ObjectExistsRequest
from AsposeEmailCloudSdk.models.storage_exists_request import StorageExistsRequest



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="ListResponseOfStorageFileLocation.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.storage_file_location import StorageFileLocation


class ListResponseOfStorageFileLocation(object):
    """
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'value': 'list[StorageFileLocation]'
    }

    attribute_map = {
        'value': 'value'
    }

    def __init__(self, value: List[StorageFileLocation] = None):
        """
        
        :param value: 
        :type value: List[StorageFileLocation]
        """

        self._value = None

        if value is not None:
            self.value = value


    @property
    def value(self) -> List[StorageFileLocation]:
        """
        Gets the value of this ListResponseOfStorageFileLocation.

        :return: The value of this ListResponseOfStorageFileLocation.
        :rtype: list[StorageFileLocation]
        """
        return self._value

    @value.setter
    def value(self, value: List[StorageFileLocation]):
        """
        Sets the value of this ListResponseOfStorageFileLocation.

        :param value: The value of this ListResponseOfStorageFileLocation.
        :type: list[StorageFileLocation]
        """
        self._value = value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListResponseOfStorageFileLocation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="AiNameCulturalContext.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime


class AiNameCulturalContext(object):
    """AiName cultural context             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'language': 'str',
        'location': 'str',
        'script': 'str',
        'encoding': 'str',
        'style': 'str'
    }

    attribute_map = {
        'language': 'language',
        'location': 'location',
        'script': 'script',
        'encoding': 'encoding',
        'style': 'style'
    }

    def __init__(self, language: str = None, location: str = None, script: str = None, encoding: str = None, style: str = None):
        """
        AiName cultural context             
        :param language: An ISO-639 code of the language; either 639-1 or 639-3 (e.g. \"it\" or \"ita\" for Italian)             
        :type language: str
        :param location: A geographic code such as an ISO-3166 two letter country code, for example \"FR\" for France             
        :type location: str
        :param script: A writing system code; starts with the ISO-15924 script name             
        :type script: str
        :param encoding: A character encoding name             
        :type encoding: str
        :param style: Name writing style. Enum, available values: Formal, Informal, Legal, Academic
        :type style: str
        """

        self._language = None
        self._location = None
        self._script = None
        self._encoding = None
        self._style = None

        if language is not None:
            self.language = language
        if location is not None:
            self.location = location
        if script is not None:
            self.script = script
        if encoding is not None:
            self.encoding = encoding
        if style is not None:
            self.style = style


    @property
    def language(self) -> str:
        """
        An ISO-639 code of the language; either 639-1 or 639-3 (e.g. \"it\" or \"ita\" for Italian)             

        :return: The language of this AiNameCulturalContext.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language: str):
        """
        An ISO-639 code of the language; either 639-1 or 639-3 (e.g. \"it\" or \"ita\" for Italian)             

        :param language: The language of this AiNameCulturalContext.
        :type: str
        """
        self._language = language

    @property
    def location(self) -> str:
        """
        A geographic code such as an ISO-3166 two letter country code, for example \"FR\" for France             

        :return: The location of this AiNameCulturalContext.
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location: str):
        """
        A geographic code such as an ISO-3166 two letter country code, for example \"FR\" for France             

        :param location: The location of this AiNameCulturalContext.
        :type: str
        """
        self._location = location

    @property
    def script(self) -> str:
        """
        A writing system code; starts with the ISO-15924 script name             

        :return: The script of this AiNameCulturalContext.
        :rtype: str
        """
        return self._script

    @script.setter
    def script(self, script: str):
        """
        A writing system code; starts with the ISO-15924 script name             

        :param script: The script of this AiNameCulturalContext.
        :type: str
        """
        self._script = script

    @property
    def encoding(self) -> str:
        """
        A character encoding name             

        :return: The encoding of this AiNameCulturalContext.
        :rtype: str
        """
        return self._encoding

    @encoding.setter
    def encoding(self, encoding: str):
        """
        A character encoding name             

        :param encoding: The encoding of this AiNameCulturalContext.
        :type: str
        """
        self._encoding = encoding

    @property
    def style(self) -> str:
        """
        Name writing style. Enum, available values: Formal, Informal, Legal, Academic

        :return: The style of this AiNameCulturalContext.
        :rtype: str
        """
        return self._style

    @style.setter
    def style(self, style: str):
        """
        Name writing style. Enum, available values: Formal, Informal, Legal, Academic

        :param style: The style of this AiNameCulturalContext.
        :type: str
        """
        if style is None:
            raise ValueError("Invalid value for `style`, must not be `None`")
        self._style = style

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AiNameCulturalContext):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="MapiContactNamePropertySetDto.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime


class MapiContactNamePropertySetDto(object):
    """The properties are used to specify the name of the person represented by the contact             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'display_name': 'str',
        'display_name_prefix': 'str',
        'file_under': 'str',
        'file_under_id': 'int',
        'generation': 'str',
        'given_name': 'str',
        'initials': 'str',
        'middle_name': 'str',
        'nickname': 'str',
        'surname': 'str'
    }

    attribute_map = {
        'display_name': 'displayName',
        'display_name_prefix': 'displayNamePrefix',
        'file_under': 'fileUnder',
        'file_under_id': 'fileUnderId',
        'generation': 'generation',
        'given_name': 'givenName',
        'initials': 'initials',
        'middle_name': 'middleName',
        'nickname': 'nickname',
        'surname': 'surname'
    }

    def __init__(self, display_name: str = None, display_name_prefix: str = None, file_under: str = None, file_under_id: int = None, generation: str = None, given_name: str = None, initials: str = None, middle_name: str = None, nickname: str = None, surname: str = None):
        """
        The properties are used to specify the name of the person represented by the contact             
        :param display_name: Full name of the contact             
        :type display_name: str
        :param display_name_prefix: Title of the contact             
        :type display_name_prefix: str
        :param file_under: Name under which to file this contact when displaying a list of contacts             
        :type file_under: str
        :param file_under_id: Value specifying how to generate and recompute the property when other properties are changed             
        :type file_under_id: int
        :param generation: Generation suffix of the contact             
        :type generation: str
        :param given_name: Given name (first name) of the contact             
        :type given_name: str
        :param initials: Initials of the contact             
        :type initials: str
        :param middle_name: Middle name of the contact             
        :type middle_name: str
        :param nickname: Nickname of the contact             
        :type nickname: str
        :param surname: Surname (family name) of the contact             
        :type surname: str
        """

        self._display_name = None
        self._display_name_prefix = None
        self._file_under = None
        self._file_under_id = None
        self._generation = None
        self._given_name = None
        self._initials = None
        self._middle_name = None
        self._nickname = None
        self._surname = None

        if display_name is not None:
            self.display_name = display_name
        if display_name_prefix is not None:
            self.display_name_prefix = display_name_prefix
        if file_under is not None:
            self.file_under = file_under
        if file_under_id is not None:
            self.file_under_id = file_under_id
        if generation is not None:
            self.generation = generation
        if given_name is not None:
            self.given_name = given_name
        if initials is not None:
            self.initials = initials
        if middle_name is not None:
            self.middle_name = middle_name
        if nickname is not None:
            self.nickname = nickname
        if surname is not None:
            self.surname = surname


    @property
    def display_name(self) -> str:
        """
        Full name of the contact             

        :return: The display_name of this MapiContactNamePropertySetDto.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name: str):
        """
        Full name of the contact             

        :param display_name: The display_name of this MapiContactNamePropertySetDto.
        :type: str
        """
        self._display_name = display_name

    @property
    def display_name_prefix(self) -> str:
        """
        Title of the contact             

        :return: The display_name_prefix of this MapiContactNamePropertySetDto.
        :rtype: str
        """
        return self._display_name_prefix

    @display_name_prefix.setter
    def display_name_prefix(self, display_name_prefix: str):
        """
        Title of the contact             

        :param display_name_prefix: The display_name_prefix of this MapiContactNamePropertySetDto.
        :type: str
        """
        self._display_name_prefix = display_name_prefix

    @property
    def file_under(self) -> str:
        """
        Name under which to file this contact when displaying a list of contacts             

        :return: The file_under of this MapiContactNamePropertySetDto.
        :rtype: str
        """
        return self._file_under

    @file_under.setter
    def file_under(self, file_under: str):
        """
        Name under which to file this contact when displaying a list of contacts             

        :param file_under: The file_under of this MapiContactNamePropertySetDto.
        :type: str
        """
        self._file_under = file_under

    @property
    def file_under_id(self) -> int:
        """
        Value specifying how to generate and recompute the property when other properties are changed             

        :return: The file_under_id of this MapiContactNamePropertySetDto.
        :rtype: int
        """
        return self._file_under_id

    @file_under_id.setter
    def file_under_id(self, file_under_id: int):
        """
        Value specifying how to generate and recompute the property when other properties are changed             

        :param file_under_id: The file_under_id of this MapiContactNamePropertySetDto.
        :type: int
        """
        if file_under_id is None:
            raise ValueError("Invalid value for `file_under_id`, must not be `None`")
        self._file_under_id = file_under_id

    @property
    def generation(self) -> str:
        """
        Generation suffix of the contact             

        :return: The generation of this MapiContactNamePropertySetDto.
        :rtype: str
        """
        return self._generation

    @generation.setter
    def generation(self, generation: str):
        """
        Generation suffix of the contact             

        :param generation: The generation of this MapiContactNamePropertySetDto.
        :type: str
        """
        self._generation = generation

    @property
    def given_name(self) -> str:
        """
        Given name (first name) of the contact             

        :return: The given_name of this MapiContactNamePropertySetDto.
        :rtype: str
        """
        return self._given_name

    @given_name.setter
    def given_name(self, given_name: str):
        """
        Given name (first name) of the contact             

        :param given_name: The given_name of this MapiContactNamePropertySetDto.
        :type: str
        """
        self._given_name = given_name

    @property
    def initials(self) -> str:
        """
        Initials of the contact             

        :return: The initials of this MapiContactNamePropertySetDto.
        :rtype: str
        """
        return self._initials

    @initials.setter
    def initials(self, initials: str):
        """
        Initials of the contact             

        :param initials: The initials of this MapiContactNamePropertySetDto.
        :type: str
        """
        self._initials = initials

    @property
    def middle_name(self) -> str:
        """
        Middle name of the contact             

        :return: The middle_name of this MapiContactNamePropertySetDto.
        :rtype: str
        """
        return self._middle_name

    @middle_name.setter
    def middle_name(self, middle_name: str):
        """
        Middle name of the contact             

        :param middle_name: The middle_name of this MapiContactNamePropertySetDto.
        :type: str
        """
        self._middle_name = middle_name

    @property
    def nickname(self) -> str:
        """
        Nickname of the contact             

        :return: The nickname of this MapiContactNamePropertySetDto.
        :rtype: str
        """
        return self._nickname

    @nickname.setter
    def nickname(self, nickname: str):
        """
        Nickname of the contact             

        :param nickname: The nickname of this MapiContactNamePropertySetDto.
        :type: str
        """
        self._nickname = nickname

    @property
    def surname(self) -> str:
        """
        Surname (family name) of the contact             

        :return: The surname of this MapiContactNamePropertySetDto.
        :rtype: str
        """
        return self._surname

    @surname.setter
    def surname(self, surname: str):
        """
        Surname (family name) of the contact             

        :param surname: The surname of this MapiContactNamePropertySetDto.
        :type: str
        """
        self._surname = surname

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MapiContactNamePropertySetDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="__init__.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import

# import apis into api package
from AsposeEmailCloudSdk.api.ai_bcr_api import AiBcrApi
from AsposeEmailCloudSdk.api.ai_name_api import AiNameApi
from AsposeEmailCloudSdk.api.calendar_api import CalendarApi
from AsposeEmailCloudSdk.api.client_account_api import ClientAccountApi
from AsposeEmailCloudSdk.api.client_folder_api import ClientFolderApi
from AsposeEmailCloudSdk.api.client_message_api import ClientMessageApi
from AsposeEmailCloudSdk.api.client_thread_api import ClientThreadApi
from AsposeEmailCloudSdk.api.contact_api import ContactApi
from AsposeEmailCloudSdk.api.disposable_email_api import DisposableEmailApi
from AsposeEmailCloudSdk.api.email_api import EmailApi
from AsposeEmailCloudSdk.api.email_config_api import EmailConfigApi
from AsposeEmailCloudSdk.api.file_api import FileApi
from AsposeEmailCloudSdk.api.folder_api import FolderApi
from AsposeEmailCloudSdk.api.mapi_calendar_api import MapiCalendarApi
from AsposeEmailCloudSdk.api.mapi_contact_api import MapiContactApi
from AsposeEmailCloudSdk.api.mapi_message_api import MapiMessageApi
from AsposeEmailCloudSdk.api.storage_api import StorageApi

# EmailCloud imports
from AsposeEmailCloudSdk.api.mapi_group import MapiGroup
from AsposeEmailCloudSdk.api.client_group import ClientGroup
from AsposeEmailCloudSdk.api.ai_group import AiGroup
from AsposeEmailCloudSdk.api.cloud_storage_group import CloudStorageGroup
from AsposeEmailCloudSdk.api.email_cloud import EmailCloud



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="MapiContactPersonalInfoPropertySetDto.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime


class MapiContactPersonalInfoPropertySetDto(object):
    """Specify other additional contact information.             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'spouse_name': 'str',
        'personal_home_page': 'str',
        'language': 'str',
        'notes': 'str',
        'hobbies': 'str',
        'location': 'str',
        'instant_messaging_address': 'str',
        'organizational_id_number': 'str',
        'customer_id': 'str',
        'government_id_number': 'str',
        'free_busy_location': 'str',
        'account': 'str',
        'html': 'str',
        'business_home_page': 'str',
        'ftp_site': 'str',
        'computer_network_name': 'str',
        'gender': 'str',
        'referred_by_name': 'str',
        'children': 'list[str]'
    }

    attribute_map = {
        'spouse_name': 'spouseName',
        'personal_home_page': 'personalHomePage',
        'language': 'language',
        'notes': 'notes',
        'hobbies': 'hobbies',
        'location': 'location',
        'instant_messaging_address': 'instantMessagingAddress',
        'organizational_id_number': 'organizationalIdNumber',
        'customer_id': 'customerId',
        'government_id_number': 'governmentIdNumber',
        'free_busy_location': 'freeBusyLocation',
        'account': 'account',
        'html': 'html',
        'business_home_page': 'businessHomePage',
        'ftp_site': 'ftpSite',
        'computer_network_name': 'computerNetworkName',
        'gender': 'gender',
        'referred_by_name': 'referredByName',
        'children': 'children'
    }

    def __init__(self, spouse_name: str = None, personal_home_page: str = None, language: str = None, notes: str = None, hobbies: str = None, location: str = None, instant_messaging_address: str = None, organizational_id_number: str = None, customer_id: str = None, government_id_number: str = None, free_busy_location: str = None, account: str = None, html: str = None, business_home_page: str = None, ftp_site: str = None, computer_network_name: str = None, gender: str = None, referred_by_name: str = None, children: List[str] = None):
        """
        Specify other additional contact information.             
        :param spouse_name: Specifies the name of the contact's spouse/partner             
        :type spouse_name: str
        :param personal_home_page: Specifies the contact's personal web page URL             
        :type personal_home_page: str
        :param language: Specifies the language that the contact uses             
        :type language: str
        :param notes: Specifies the additional notes             
        :type notes: str
        :param hobbies: Specifies the hobbies of the contact             
        :type hobbies: str
        :param location: Specifies the location of the contact             
        :type location: str
        :param instant_messaging_address: Specifies the contact's instant messaging address             
        :type instant_messaging_address: str
        :param organizational_id_number: Specifies an organizational ID number for the contact             
        :type organizational_id_number: str
        :param customer_id: Specifies the contact's customer ID number             
        :type customer_id: str
        :param government_id_number: Specifies the contact's government ID number             
        :type government_id_number: str
        :param free_busy_location: Specifies a URL path from which a client can retrieve free/busy information for the contact as an iCal file             
        :type free_busy_location: str
        :param account: Specifies the account name of the contact             
        :type account: str
        :param html: Specifies the contact's business web page URL             
        :type html: str
        :param business_home_page: Specifies the contact's business web page URL             
        :type business_home_page: str
        :param ftp_site: Specifies the contact's File Transfer Protocol (FTP) URL             
        :type ftp_site: str
        :param computer_network_name: Specifies the name of the network to which the contact's computer is connected             
        :type computer_network_name: str
        :param gender: Gender of the contact Enum, available values: Unspecified, Female, Male
        :type gender: str
        :param referred_by_name: Specifies the name of the person who referred this contact to the user             
        :type referred_by_name: str
        :param children: Contains a list of names of children.             
        :type children: List[str]
        """

        self._spouse_name = None
        self._personal_home_page = None
        self._language = None
        self._notes = None
        self._hobbies = None
        self._location = None
        self._instant_messaging_address = None
        self._organizational_id_number = None
        self._customer_id = None
        self._government_id_number = None
        self._free_busy_location = None
        self._account = None
        self._html = None
        self._business_home_page = None
        self._ftp_site = None
        self._computer_network_name = None
        self._gender = None
        self._referred_by_name = None
        self._children = None

        if spouse_name is not None:
            self.spouse_name = spouse_name
        if personal_home_page is not None:
            self.personal_home_page = personal_home_page
        if language is not None:
            self.language = language
        if notes is not None:
            self.notes = notes
        if hobbies is not None:
            self.hobbies = hobbies
        if location is not None:
            self.location = location
        if instant_messaging_address is not None:
            self.instant_messaging_address = instant_messaging_address
        if organizational_id_number is not None:
            self.organizational_id_number = organizational_id_number
        if customer_id is not None:
            self.customer_id = customer_id
        if government_id_number is not None:
            self.government_id_number = government_id_number
        if free_busy_location is not None:
            self.free_busy_location = free_busy_location
        if account is not None:
            self.account = account
        if html is not None:
            self.html = html
        if business_home_page is not None:
            self.business_home_page = business_home_page
        if ftp_site is not None:
            self.ftp_site = ftp_site
        if computer_network_name is not None:
            self.computer_network_name = computer_network_name
        if gender is not None:
            self.gender = gender
        if referred_by_name is not None:
            self.referred_by_name = referred_by_name
        if children is not None:
            self.children = children


    @property
    def spouse_name(self) -> str:
        """
        Specifies the name of the contact's spouse/partner             

        :return: The spouse_name of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._spouse_name

    @spouse_name.setter
    def spouse_name(self, spouse_name: str):
        """
        Specifies the name of the contact's spouse/partner             

        :param spouse_name: The spouse_name of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._spouse_name = spouse_name

    @property
    def personal_home_page(self) -> str:
        """
        Specifies the contact's personal web page URL             

        :return: The personal_home_page of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._personal_home_page

    @personal_home_page.setter
    def personal_home_page(self, personal_home_page: str):
        """
        Specifies the contact's personal web page URL             

        :param personal_home_page: The personal_home_page of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._personal_home_page = personal_home_page

    @property
    def language(self) -> str:
        """
        Specifies the language that the contact uses             

        :return: The language of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language: str):
        """
        Specifies the language that the contact uses             

        :param language: The language of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._language = language

    @property
    def notes(self) -> str:
        """
        Specifies the additional notes             

        :return: The notes of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes: str):
        """
        Specifies the additional notes             

        :param notes: The notes of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._notes = notes

    @property
    def hobbies(self) -> str:
        """
        Specifies the hobbies of the contact             

        :return: The hobbies of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._hobbies

    @hobbies.setter
    def hobbies(self, hobbies: str):
        """
        Specifies the hobbies of the contact             

        :param hobbies: The hobbies of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._hobbies = hobbies

    @property
    def location(self) -> str:
        """
        Specifies the location of the contact             

        :return: The location of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location: str):
        """
        Specifies the location of the contact             

        :param location: The location of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._location = location

    @property
    def instant_messaging_address(self) -> str:
        """
        Specifies the contact's instant messaging address             

        :return: The instant_messaging_address of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._instant_messaging_address

    @instant_messaging_address.setter
    def instant_messaging_address(self, instant_messaging_address: str):
        """
        Specifies the contact's instant messaging address             

        :param instant_messaging_address: The instant_messaging_address of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._instant_messaging_address = instant_messaging_address

    @property
    def organizational_id_number(self) -> str:
        """
        Specifies an organizational ID number for the contact             

        :return: The organizational_id_number of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._organizational_id_number

    @organizational_id_number.setter
    def organizational_id_number(self, organizational_id_number: str):
        """
        Specifies an organizational ID number for the contact             

        :param organizational_id_number: The organizational_id_number of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._organizational_id_number = organizational_id_number

    @property
    def customer_id(self) -> str:
        """
        Specifies the contact's customer ID number             

        :return: The customer_id of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._customer_id

    @customer_id.setter
    def customer_id(self, customer_id: str):
        """
        Specifies the contact's customer ID number             

        :param customer_id: The customer_id of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._customer_id = customer_id

    @property
    def government_id_number(self) -> str:
        """
        Specifies the contact's government ID number             

        :return: The government_id_number of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._government_id_number

    @government_id_number.setter
    def government_id_number(self, government_id_number: str):
        """
        Specifies the contact's government ID number             

        :param government_id_number: The government_id_number of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._government_id_number = government_id_number

    @property
    def free_busy_location(self) -> str:
        """
        Specifies a URL path from which a client can retrieve free/busy information for the contact as an iCal file             

        :return: The free_busy_location of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._free_busy_location

    @free_busy_location.setter
    def free_busy_location(self, free_busy_location: str):
        """
        Specifies a URL path from which a client can retrieve free/busy information for the contact as an iCal file             

        :param free_busy_location: The free_busy_location of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._free_busy_location = free_busy_location

    @property
    def account(self) -> str:
        """
        Specifies the account name of the contact             

        :return: The account of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account: str):
        """
        Specifies the account name of the contact             

        :param account: The account of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._account = account

    @property
    def html(self) -> str:
        """
        Specifies the contact's business web page URL             

        :return: The html of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._html

    @html.setter
    def html(self, html: str):
        """
        Specifies the contact's business web page URL             

        :param html: The html of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._html = html

    @property
    def business_home_page(self) -> str:
        """
        Specifies the contact's business web page URL             

        :return: The business_home_page of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._business_home_page

    @business_home_page.setter
    def business_home_page(self, business_home_page: str):
        """
        Specifies the contact's business web page URL             

        :param business_home_page: The business_home_page of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._business_home_page = business_home_page

    @property
    def ftp_site(self) -> str:
        """
        Specifies the contact's File Transfer Protocol (FTP) URL             

        :return: The ftp_site of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._ftp_site

    @ftp_site.setter
    def ftp_site(self, ftp_site: str):
        """
        Specifies the contact's File Transfer Protocol (FTP) URL             

        :param ftp_site: The ftp_site of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._ftp_site = ftp_site

    @property
    def computer_network_name(self) -> str:
        """
        Specifies the name of the network to which the contact's computer is connected             

        :return: The computer_network_name of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._computer_network_name

    @computer_network_name.setter
    def computer_network_name(self, computer_network_name: str):
        """
        Specifies the name of the network to which the contact's computer is connected             

        :param computer_network_name: The computer_network_name of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._computer_network_name = computer_network_name

    @property
    def gender(self) -> str:
        """
        Gender of the contact Enum, available values: Unspecified, Female, Male

        :return: The gender of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._gender

    @gender.setter
    def gender(self, gender: str):
        """
        Gender of the contact Enum, available values: Unspecified, Female, Male

        :param gender: The gender of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        if gender is None:
            raise ValueError("Invalid value for `gender`, must not be `None`")
        self._gender = gender

    @property
    def referred_by_name(self) -> str:
        """
        Specifies the name of the person who referred this contact to the user             

        :return: The referred_by_name of this MapiContactPersonalInfoPropertySetDto.
        :rtype: str
        """
        return self._referred_by_name

    @referred_by_name.setter
    def referred_by_name(self, referred_by_name: str):
        """
        Specifies the name of the person who referred this contact to the user             

        :param referred_by_name: The referred_by_name of this MapiContactPersonalInfoPropertySetDto.
        :type: str
        """
        self._referred_by_name = referred_by_name

    @property
    def children(self) -> List[str]:
        """
        Contains a list of names of children.             

        :return: The children of this MapiContactPersonalInfoPropertySetDto.
        :rtype: list[str]
        """
        return self._children

    @children.setter
    def children(self, children: List[str]):
        """
        Contains a list of names of children.             

        :param children: The children of this MapiContactPersonalInfoPropertySetDto.
        :type: list[str]
        """
        self._children = children

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MapiContactPersonalInfoPropertySetDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="cloud_storage_group.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from __future__ import absolute_import
from AsposeEmailCloudSdk.api import *


class CloudStorageGroup(object):
    """
    Cloud file storage operations.
    """
    def __init__(self, api_client):
        self._file = FileApi(api_client)
        self._folder = FolderApi(api_client)
        self._storage = StorageApi(api_client)

    @property
    def file(self) -> FileApi:
        """
        File operations controller
        """
        return self._file

    @property
    def folder(self) -> FolderApi:
        """
        Folder operations controller
        """
        return self._folder

    @property
    def storage(self) -> StorageApi:
        """
        Storage operations controller
        """
        return self._storage



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="ai_name_parse_request.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

from AsposeEmailCloudSdk.models import *


class AiNameParseRequest(object):
    """
    Request model for ai_name_parse operation.
    Initializes a new instance.

    :param name: A name to parse.
    :type name: str
    :param language: An ISO-639 code of the language; either 639-1 or 639-3 (e.g. \"it\" or \"ita\" for Italian).             
    :type language: str
    :param location: A geographic code such as an ISO-3166 two letter country code, for example \"FR\" for France.             
    :type location: str
    :param encoding: A character encoding name.
    :type encoding: str
    :param script: A writing system code; starts with the ISO-15924 script name.
    :type script: str
    :param style: Name writing style. Enum, available values: Formal, Informal, Legal, Academic
    :type style: str
    """

    def __init__(self, name: str, language: str = None, location: str = None, encoding: str = None, script: str = None, style: str = None):
        """
        Request model for ai_name_parse operation.
        Initializes a new instance.

        :param name: A name to parse.
        :type name: str
        :param language: An ISO-639 code of the language; either 639-1 or 639-3 (e.g. \"it\" or \"ita\" for Italian).             
        :type language: str
        :param location: A geographic code such as an ISO-3166 two letter country code, for example \"FR\" for France.             
        :type location: str
        :param encoding: A character encoding name.
        :type encoding: str
        :param script: A writing system code; starts with the ISO-15924 script name.
        :type script: str
        :param style: Name writing style. Enum, available values: Formal, Informal, Legal, Academic
        :type style: str
        """

        self.name = name
        self.language = language
        self.location = location
        self.encoding = encoding
        self.script = script
        self.style = style



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="MapiContactOtherPropertySetDto.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime


class MapiContactOtherPropertySetDto(object):
    """The properties are used to specify additional properties of contact.             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'private': 'bool',
        'journal': 'bool',
        'reminder_time': 'datetime',
        'reminder_topic': 'str',
        'user_field1': 'str',
        'user_field2': 'str',
        'user_field3': 'str',
        'user_field4': 'str'
    }

    attribute_map = {
        'private': 'private',
        'journal': 'journal',
        'reminder_time': 'reminderTime',
        'reminder_topic': 'reminderTopic',
        'user_field1': 'userField1',
        'user_field2': 'userField2',
        'user_field3': 'userField3',
        'user_field4': 'userField4'
    }

    def __init__(self, private: bool = None, journal: bool = None, reminder_time: datetime = None, reminder_topic: str = None, user_field1: str = None, user_field2: str = None, user_field3: str = None, user_field4: str = None):
        """
        The properties are used to specify additional properties of contact.             
        :param private: Indicates whether the end-user wants this message object hidden from other users who have access to the message object.             
        :type private: bool
        :param journal: Specifies whether to create a journal for each action associated with this contact.             
        :type journal: bool
        :param reminder_time: Specifies the initial signal time for a reminder.             
        :type reminder_time: datetime
        :param reminder_topic: Represents the status of a meeting request.             
        :type reminder_topic: str
        :param user_field1: Specifies the first field on the contact that is intended for miscellaneous use for the contact.             
        :type user_field1: str
        :param user_field2: Specifies the second field on the contact that is intended for miscellaneous use for the contact.             
        :type user_field2: str
        :param user_field3: Specifies the third field on the contact that is intended for miscellaneous use for the contact.             
        :type user_field3: str
        :param user_field4: Specifies the forth field on the contact that is intended for miscellaneous use for the contact.             
        :type user_field4: str
        """

        self._private = None
        self._journal = None
        self._reminder_time = None
        self._reminder_topic = None
        self._user_field1 = None
        self._user_field2 = None
        self._user_field3 = None
        self._user_field4 = None

        if private is not None:
            self.private = private
        if journal is not None:
            self.journal = journal
        if reminder_time is not None:
            self.reminder_time = reminder_time
        if reminder_topic is not None:
            self.reminder_topic = reminder_topic
        if user_field1 is not None:
            self.user_field1 = user_field1
        if user_field2 is not None:
            self.user_field2 = user_field2
        if user_field3 is not None:
            self.user_field3 = user_field3
        if user_field4 is not None:
            self.user_field4 = user_field4


    @property
    def private(self) -> bool:
        """
        Indicates whether the end-user wants this message object hidden from other users who have access to the message object.             

        :return: The private of this MapiContactOtherPropertySetDto.
        :rtype: bool
        """
        return self._private

    @private.setter
    def private(self, private: bool):
        """
        Indicates whether the end-user wants this message object hidden from other users who have access to the message object.             

        :param private: The private of this MapiContactOtherPropertySetDto.
        :type: bool
        """
        if private is None:
            raise ValueError("Invalid value for `private`, must not be `None`")
        self._private = private

    @property
    def journal(self) -> bool:
        """
        Specifies whether to create a journal for each action associated with this contact.             

        :return: The journal of this MapiContactOtherPropertySetDto.
        :rtype: bool
        """
        return self._journal

    @journal.setter
    def journal(self, journal: bool):
        """
        Specifies whether to create a journal for each action associated with this contact.             

        :param journal: The journal of this MapiContactOtherPropertySetDto.
        :type: bool
        """
        if journal is None:
            raise ValueError("Invalid value for `journal`, must not be `None`")
        self._journal = journal

    @property
    def reminder_time(self) -> datetime:
        """
        Specifies the initial signal time for a reminder.             

        :return: The reminder_time of this MapiContactOtherPropertySetDto.
        :rtype: datetime
        """
        return self._reminder_time

    @reminder_time.setter
    def reminder_time(self, reminder_time: datetime):
        """
        Specifies the initial signal time for a reminder.             

        :param reminder_time: The reminder_time of this MapiContactOtherPropertySetDto.
        :type: datetime
        """
        if reminder_time is None:
            raise ValueError("Invalid value for `reminder_time`, must not be `None`")
        self._reminder_time = reminder_time

    @property
    def reminder_topic(self) -> str:
        """
        Represents the status of a meeting request.             

        :return: The reminder_topic of this MapiContactOtherPropertySetDto.
        :rtype: str
        """
        return self._reminder_topic

    @reminder_topic.setter
    def reminder_topic(self, reminder_topic: str):
        """
        Represents the status of a meeting request.             

        :param reminder_topic: The reminder_topic of this MapiContactOtherPropertySetDto.
        :type: str
        """
        self._reminder_topic = reminder_topic

    @property
    def user_field1(self) -> str:
        """
        Specifies the first field on the contact that is intended for miscellaneous use for the contact.             

        :return: The user_field1 of this MapiContactOtherPropertySetDto.
        :rtype: str
        """
        return self._user_field1

    @user_field1.setter
    def user_field1(self, user_field1: str):
        """
        Specifies the first field on the contact that is intended for miscellaneous use for the contact.             

        :param user_field1: The user_field1 of this MapiContactOtherPropertySetDto.
        :type: str
        """
        self._user_field1 = user_field1

    @property
    def user_field2(self) -> str:
        """
        Specifies the second field on the contact that is intended for miscellaneous use for the contact.             

        :return: The user_field2 of this MapiContactOtherPropertySetDto.
        :rtype: str
        """
        return self._user_field2

    @user_field2.setter
    def user_field2(self, user_field2: str):
        """
        Specifies the second field on the contact that is intended for miscellaneous use for the contact.             

        :param user_field2: The user_field2 of this MapiContactOtherPropertySetDto.
        :type: str
        """
        self._user_field2 = user_field2

    @property
    def user_field3(self) -> str:
        """
        Specifies the third field on the contact that is intended for miscellaneous use for the contact.             

        :return: The user_field3 of this MapiContactOtherPropertySetDto.
        :rtype: str
        """
        return self._user_field3

    @user_field3.setter
    def user_field3(self, user_field3: str):
        """
        Specifies the third field on the contact that is intended for miscellaneous use for the contact.             

        :param user_field3: The user_field3 of this MapiContactOtherPropertySetDto.
        :type: str
        """
        self._user_field3 = user_field3

    @property
    def user_field4(self) -> str:
        """
        Specifies the forth field on the contact that is intended for miscellaneous use for the contact.             

        :return: The user_field4 of this MapiContactOtherPropertySetDto.
        :rtype: str
        """
        return self._user_field4

    @user_field4.setter
    def user_field4(self, user_field4: str):
        """
        Specifies the forth field on the contact that is intended for miscellaneous use for the contact.             

        :param user_field4: The user_field4 of this MapiContactOtherPropertySetDto.
        :type: str
        """
        self._user_field4 = user_field4

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MapiContactOtherPropertySetDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



#  coding: utf-8
#  ----------------------------------------------------------------------------
#  <copyright company="Aspose" file="MapiCalendarDailyRecurrencePatternDto.py">
#    Copyright (c) 2018-2020 Aspose Pty Ltd. All rights reserved.
#  </copyright>
#  <summary>
#    Permission is hereby granted, free of charge, to any person obtaining a
#   copy  of this software and associated documentation files (the "Software"),
#   to deal  in the Software without restriction, including without limitation
#   the rights  to use, copy, modify, merge, publish, distribute, sublicense,
#   and/or sell  copies of the Software, and to permit persons to whom the
#   Software is  furnished to do so, subject to the following conditions:
#
#   The above copyright notice and this permission notice shall be included in
#   all  copies or substantial portions of the Software.
#
#   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
#   IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
#   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
#   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
#   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#   FROM,  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
#   DEALINGS IN THE SOFTWARE.
#  </summary>
#  ----------------------------------------------------------------------------

import pprint
import re
import six
from typing import List, Set, Dict, Tuple, Optional
from datetime import datetime

from AsposeEmailCloudSdk.models.mapi_calendar_exception_info_dto import MapiCalendarExceptionInfoDto
from AsposeEmailCloudSdk.models.mapi_calendar_recurrence_pattern_dto import MapiCalendarRecurrencePatternDto


class MapiCalendarDailyRecurrencePatternDto(MapiCalendarRecurrencePatternDto):
    """Represents the daily recurrence pattern of the mapi calendar.             
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'calendar_type': 'str',
        'deleted_instance_dates': 'list[datetime]',
        'end_date': 'datetime',
        'end_type': 'str',
        'exceptions': 'list[MapiCalendarExceptionInfoDto]',
        'frequency': 'str',
        'modified_instance_dates': 'list[datetime]',
        'occurrence_count': 'int',
        'pattern_type': 'str',
        'period': 'int',
        'sliding_flag': 'bool',
        'start_date': 'datetime',
        'week_start_day': 'str',
        'discriminator': 'str',
        'day_of_week': 'list[str]'
    }

    attribute_map = {
        'calendar_type': 'calendarType',
        'deleted_instance_dates': 'deletedInstanceDates',
        'end_date': 'endDate',
        'end_type': 'endType',
        'exceptions': 'exceptions',
        'frequency': 'frequency',
        'modified_instance_dates': 'modifiedInstanceDates',
        'occurrence_count': 'occurrenceCount',
        'pattern_type': 'patternType',
        'period': 'period',
        'sliding_flag': 'slidingFlag',
        'start_date': 'startDate',
        'week_start_day': 'weekStartDay',
        'discriminator': 'discriminator',
        'day_of_week': 'dayOfWeek'
    }

    def __init__(self, calendar_type: str = None, deleted_instance_dates: List[datetime] = None, end_date: datetime = None, end_type: str = None, exceptions: List[MapiCalendarExceptionInfoDto] = None, frequency: str = None, modified_instance_dates: List[datetime] = None, occurrence_count: int = None, pattern_type: str = None, period: int = None, sliding_flag: bool = None, start_date: datetime = None, week_start_day: str = None, day_of_week: List[str] = None):
        """
        Represents the daily recurrence pattern of the mapi calendar.             
        :param calendar_type: Enumerated the calendar type of the mapi recurrence Enum, available values: Default, CalGregorian, CalGregorianUs, CalJapan, CalTaiwan, CalKorea, CalHijri, CalThai, CalHebrew, CalGregorianMeFrench, CalGregorianArabic, CalGregorianXLitEnglish, CalGregorianXLitFrench, CalLunarJapanese, CalChineseLunar, CalSaka, CalLunarEtoChn, CalLunarEtoKor, CalLunarRokuyou, CalLunarKorean, CalUmAlQura
        :type calendar_type: str
        :param deleted_instance_dates: An array of dates, each of which is the original instance date of either a deleted instance or a modified instance for this recurrence.             
        :type deleted_instance_dates: List[datetime]
        :param end_date: End date of an item recurrence pattern.             
        :type end_date: datetime
        :param end_type: Enumerates the ending type for the recurrence. Enum, available values: None, EndAfterDate, EndAfterNOccurrences, NeverEnd
        :type end_type: str
        :param exceptions: An exception specifies changes to an instance of a recurring series.             
        :type exceptions: List[MapiCalendarExceptionInfoDto]
        :param frequency: Enumerates mapi calendar recurrence frequency Enum, available values: None, Daily, Weekly, Monthly, Yearly
        :type frequency: str
        :param modified_instance_dates: An array of dates, each of which is the date of a modified instance.             
        :type modified_instance_dates: List[datetime]
        :param occurrence_count: Number of occurrences in a recurrence.             
        :type occurrence_count: int
        :param pattern_type: Enumerates the mapi calendar recurrence pattern types Enum, available values: Day, Week, Month, MonthEnd, MonthNth, HjMonth, HjMonthNth, HjMonthEnd
        :type pattern_type: str
        :param period: Interval at which the meeting pattern repeats.             
        :type period: int
        :param sliding_flag: Defines whether pattern is sliding or not.             
        :type sliding_flag: bool
        :param start_date: Start date of an item recurrence pattern.             
        :type start_date: datetime
        :param week_start_day: Day of week. Enum, available values: Sunday, Monday, Tuesday, Wednesday, Thursday, Friday, Saturday
        :type week_start_day: str
        :param day_of_week: Days of week at which the event occurs.             
        :type day_of_week: List[str]
        """
        super(MapiCalendarDailyRecurrencePatternDto, self).__init__()

        self._day_of_week = None

        if calendar_type is not None:
            self.calendar_type = calendar_type
        if deleted_instance_dates is not None:
            self.deleted_instance_dates = deleted_instance_dates
        if end_date is not None:
            self.end_date = end_date
        if end_type is not None:
            self.end_type = end_type
        if exceptions is not None:
            self.exceptions = exceptions
        if frequency is not None:
            self.frequency = frequency
        if modified_instance_dates is not None:
            self.modified_instance_dates = modified_instance_dates
        if occurrence_count is not None:
            self.occurrence_count = occurrence_count
        if pattern_type is not None:
            self.pattern_type = pattern_type
        if period is not None:
            self.period = period
        if sliding_flag is not None:
            self.sliding_flag = sliding_flag
        if start_date is not None:
            self.start_date = start_date
        if week_start_day is not None:
            self.week_start_day = week_start_day
        if day_of_week is not None:
            self.day_of_week = day_of_week


    @property
    def day_of_week(self) -> List[str]:
        """
        Days of week at which the event occurs.              Items: Enumerates the days of week of the mapi calendar recurrence pattern Enum, available values: Saturday, Friday, Thursday, Wednesday, Tuesday, Monday, Sunday

        :return: The day_of_week of this MapiCalendarDailyRecurrencePatternDto.
        :rtype: list[str]
        """
        return self._day_of_week

    @day_of_week.setter
    def day_of_week(self, day_of_week: List[str]):
        """
        Days of week at which the event occurs.              Items: Enumerates the days of week of the mapi calendar recurrence pattern Enum, available values: Saturday, Friday, Thursday, Wednesday, Tuesday, Monday, Sunday

        :param day_of_week: The day_of_week of this MapiCalendarDailyRecurrencePatternDto.
        :type: list[str]
        """
        self._day_of_week = day_of_week

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MapiCalendarDailyRecurrencePatternDto):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
